<?php

/**
 * Initialize Custom Post Type - Groppe Theme
 */

function groppe_custom_post_type() {

	$project_cpt = (groppe_framework_active()) ? cs_get_option('theme_project_name') : '';
	$project_slug = (groppe_framework_active()) ? cs_get_option('theme_project_slug') : '';
	$project_cpt_slug = (groppe_framework_active()) ? cs_get_option('theme_project_cat_slug') : '';

	$base = ($project_cpt_slug && $project_cpt_slug !== '') ? sanitize_title_with_dashes($project_cpt_slug) : (($project_cpt && $project_cpt !== '') ? strtolower($project_cpt) : 'project');
	$base_slug = ($project_slug && $project_slug !== '') ? sanitize_title_with_dashes($project_slug) : (($project_cpt && $project_cpt !== '') ? strtolower($project_cpt) : 'project');
	$label = ucfirst(($project_cpt && $project_cpt !== '') ? strtolower($project_cpt) : 'project');

	// Register custom post type - Project
	register_post_type('project',
		array(
			'labels' => array(
				'name' => $label,
				'singular_name' => sprintf(esc_html__('%s Post', 'groppe-core' ), $label),
				'all_items' => sprintf(esc_html__('All %s', 'groppe-core' ), $label),
				'add_new' => esc_html__('Add New', 'groppe-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'groppe-core' ), $label),
				'edit' => esc_html__('Edit', 'groppe-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'groppe-core' ), $label),
				'new_item' => sprintf(esc_html__('New %s', 'groppe-core' ), $label),
				'view_item' => sprintf(esc_html__('View %s', 'groppe-core' ), $label),
				'search_items' => sprintf(esc_html__('Search %s', 'groppe-core' ), $label),
				'not_found' => esc_html__('Nothing found in the Database.', 'groppe-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'groppe-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			'menu_position' => 10,
			'menu_icon' => 'dashicons-portfolio',
			'rewrite' => array(
				'slug' => $base_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'author',
				'thumbnail',
				'excerpt',
				'trackbacks',
				'custom-fields',
				'comments',
				'revisions',
				'sticky',
				'page-attributes'
			)
		)
	);
	// Registered

	// Add Category Taxonomy for our Custom Post Type - Project
	register_taxonomy(
		'project_category',
		'project',
		array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'labels' => array(
				'name' => sprintf(esc_html__( '%s Categories', 'groppe-core' ), $label),
				'singular_name' => sprintf(esc_html__('%s Category', 'groppe-core'), $label),
				'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'groppe-core'), $label),
				'all_items' => sprintf(esc_html__( 'All %s Categories', 'groppe-core'), $label),
				'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'groppe-core'), $label),
				'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'groppe-core'), $label),
				'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'groppe-core'), $label),
				'update_item' => sprintf(esc_html__( 'Update %s Category', 'groppe-core'), $label),
				'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'groppe-core'), $label),
				'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'groppe-core'), $label)
			),
			'rewrite' => array( 'slug' => $base . '_cat' ),
		)
	);
	register_taxonomy(
    'project_tag',
    'project',
    array(
        'hierarchical'  => false,
        'labels' => array(
					'name' => sprintf(esc_html__( '%s Tags', 'groppe-core' ), $label),
					'singular_name' => sprintf(esc_html__('%s Tag', 'groppe-core'), $label),
					'search_items' =>  sprintf(esc_html__( 'Search %s Tags', 'groppe-core'), $label),
					'all_items' => sprintf(esc_html__( 'All %s Tags', 'groppe-core'), $label),
					'parent_item' => sprintf(esc_html__( 'Parent %s Tag', 'groppe-core'), $label),
					'parent_item_colon' => sprintf(esc_html__( 'Parent %s Tag:', 'groppe-core'), $label),
					'edit_item' => sprintf(esc_html__( 'Edit %s Tag', 'groppe-core'), $label),
					'update_item' => sprintf(esc_html__( 'Update %s Tag', 'groppe-core'), $label),
					'add_new_item' => sprintf(esc_html__( 'Add New %s Tag', 'groppe-core'), $label),
					'new_item_name' => sprintf(esc_html__( 'New %s Tag Name', 'groppe-core'), $label)
				),
        'rewrite'       => true,
        'query_var'     => true
    )
	);

	$gallery_cpt = (groppe_framework_active()) ? cs_get_option('theme_gallery_name') : '';
	$gallery_slug = (groppe_framework_active()) ? cs_get_option('theme_gallery_slug') : '';
	$gallery_cpt_slug = (groppe_framework_active()) ? cs_get_option('theme_gallery_cat_slug') : '';
	$base = ($gallery_cpt_slug && $gallery_cpt_slug !== '') ? sanitize_title_with_dashes($gallery_cpt_slug) : (($gallery_cpt && $gallery_cpt !== '') ? strtolower($gallery_cpt) : 'gallery');
	$base_slug = ($gallery_slug && $gallery_slug !== '') ? sanitize_title_with_dashes($gallery_slug) : (($gallery_cpt && $gallery_cpt !== '') ? strtolower($gallery_cpt) : 'gallery');
	$gallery_label = ucfirst(($gallery_cpt && $gallery_cpt !== '') ? strtolower($gallery_cpt) : 'gallery');

	// Register custom post type - Project
	register_post_type('gallery',
		array(
			'labels' => array(
				'name' => $gallery_label,
				'singular_name' => sprintf(esc_html__('%s Post', 'groppe-core' ), $gallery_label),
				'all_items' => sprintf(esc_html__('All %s', 'groppe-core' ), $gallery_label),
				'add_new' => esc_html__('Add New', 'groppe-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'groppe-core' ), $gallery_label),
				'edit' => esc_html__('Edit', 'groppe-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'groppe-core' ), $gallery_label),
				'new_item' => sprintf(esc_html__('New %s', 'groppe-core' ), $gallery_label),
				'view_item' => sprintf(esc_html__('View %s', 'groppe-core' ), $gallery_label),
				'search_items' => sprintf(esc_html__('Search %s', 'groppe-core' ), $gallery_label),
				'not_found' => esc_html__('Nothing found in the Database.', 'groppe-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'groppe-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			'menu_position' => 10,
			'menu_icon' => 'dashicons-portfolio',
			'rewrite' => array(
				'slug' => $base_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'thumbnail',
				'revisions',
				'author',
			)
		)
	);
	// Registered

	// Add Category Taxonomy for our Custom Post Type - Project
	register_taxonomy(
		'gallery_category',
		'gallery',
		array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'labels' => array(
				'name' => sprintf(esc_html__( '%s Categories', 'groppe-core' ), $label),
				'singular_name' => sprintf(esc_html__('%s Category', 'groppe-core'), $label),
				'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'groppe-core'), $label),
				'all_items' => sprintf(esc_html__( 'All %s Categories', 'groppe-core'), $label),
				'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'groppe-core'), $label),
				'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'groppe-core'), $label),
				'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'groppe-core'), $label),
				'update_item' => sprintf(esc_html__( 'Update %s Category', 'groppe-core'), $label),
				'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'groppe-core'), $label),
				'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'groppe-core'), $label)
			),
			'rewrite' => array( 'slug' => $base . '_cat' ),
		)
	);

	// Testimonials - Start
	$testimonial_slug = 'testimonial';
	$testimonials = __('Testimonials', 'groppe-core');

	// Register custom post type - Testimonials
	register_post_type('testimonial',
		array(
			'labels' => array(
				'name' => $testimonials,
				'singular_name' => sprintf(esc_html__('%s Post', 'groppe-core' ), $testimonials),
				'all_items' => sprintf(esc_html__('%s', 'groppe-core' ), $testimonials),
				'add_new' => esc_html__('Add New', 'groppe-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'groppe-core' ), $testimonials),
				'edit' => esc_html__('Edit', 'groppe-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'groppe-core' ), $testimonials),
				'new_item' => sprintf(esc_html__('New %s', 'groppe-core' ), $testimonials),
				'view_item' => sprintf(esc_html__('View %s', 'groppe-core' ), $testimonials),
				'search_items' => sprintf(esc_html__('Search %s', 'groppe-core' ), $testimonials),
				'not_found' => esc_html__('Nothing found in the Database.', 'groppe-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'groppe-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			// 'menu_position' => 10,
			'show_in_menu' => 'groppe_post_type',
			'menu_icon' => 'dashicons-groups',
			'rewrite' => array(
				'slug' => $testimonial_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'thumbnail',
				'revisions',
				'sticky',
			)
		)
	);
	// Testimonials - End

	// Team - Start
	$team_slug = 'team';
	$teams = __('Teams', 'groppe-core');

	// Register custom post type - Team
	register_post_type('team',
		array(
			'labels' => array(
				'name' => $teams,
				'singular_name' => sprintf(esc_html__('%s Post', 'groppe-core' ), $teams),
				'all_items' => sprintf(esc_html__('%s', 'groppe-core' ), $teams),
				'add_new' => esc_html__('Add New', 'groppe-core') ,
				'add_new_item' => sprintf(esc_html__('Add New %s', 'groppe-core' ), $teams),
				'edit' => esc_html__('Edit', 'groppe-core') ,
				'edit_item' => sprintf(esc_html__('Edit %s', 'groppe-core' ), $teams),
				'new_item' => sprintf(esc_html__('New %s', 'groppe-core' ), $teams),
				'view_item' => sprintf(esc_html__('View %s', 'groppe-core' ), $teams),
				'search_items' => sprintf(esc_html__('Search %s', 'groppe-core' ), $teams),
				'not_found' => esc_html__('Nothing found in the Database.', 'groppe-core') ,
				'not_found_in_trash' => esc_html__('Nothing found in Trash', 'groppe-core') ,
				'parent_item_colon' => ''
			) ,
			'public' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'show_ui' => true,
			'query_var' => true,
			// 'menu_position' => 10,
			'show_in_menu' => 'groppe_post_type',
			'menu_icon' => 'dashicons-businessman',
			'rewrite' => array(
				'slug' => $team_slug,
				'with_front' => false
			),
			'has_archive' => true,
			'capability_type' => 'post',
			'hierarchical' => true,
			'supports' => array(
				'title',
				'editor',
				'thumbnail',
				'excerpt',
				'revisions',
				'sticky',
			)
		)
	);
	register_taxonomy(
		'team_category',
		'team',
		array(
			'hierarchical' => true,
			'public' => true,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'labels' => array(
				'name' => sprintf(esc_html__( '%s Categories', 'groppe-core' ), $teams),
				'singular_name' => sprintf(esc_html__('%s Category', 'groppe-core'), $teams),
				'search_items' =>  sprintf(esc_html__( 'Search %s Categories', 'groppe-core'), $teams),
				'all_items' => sprintf(esc_html__( 'All %s Categories', 'groppe-core'), $teams),
				'parent_item' => sprintf(esc_html__( 'Parent %s Category', 'groppe-core'), $teams),
				'parent_item_colon' => sprintf(esc_html__( 'Parent %s Category:', 'groppe-core'), $teams),
				'edit_item' => sprintf(esc_html__( 'Edit %s Category', 'groppe-core'), $teams),
				'update_item' => sprintf(esc_html__( 'Update %s Category', 'groppe-core'), $teams),
				'add_new_item' => sprintf(esc_html__( 'Add New %s Category', 'groppe-core'), $teams),
				'new_item_name' => sprintf(esc_html__( 'New %s Category Name', 'groppe-core'), $teams)
			),
			'rewrite' => array( 'slug' => $base . '_cat' ),
		)
	);

	// Team - End

}

// Post Type - Menu
if( ! function_exists( 'groppe_post_type_menu' ) ) {
  function groppe_post_type_menu(){
    if ( current_user_can( 'edit_theme_options' ) ) {
			add_menu_page( esc_html__('Company', 'groppe-core'), esc_html__('Company', 'groppe-core'), 'edit_theme_options', 'groppe_post_type', 'vt_welcome_page', 'dashicons-groups', 10 );
    }
  }
}
add_action( 'admin_menu', 'groppe_post_type_menu' );

// Project Slug
function groppe_custom_project_slug() {
	$project_cpt = (groppe_framework_active()) ? cs_get_option('theme_project_name') : '';
	if ($project_cpt === '') $project_cp = 'project';
  $rules = get_option( 'rewrite_rules' );
  if ( ! ( $rules['('.$project_cpt.')/(\d*)$'] ) ) {
		global $wp_rewrite;
		$wp_rewrite->flush_rules();
  }

	$gallery_cpt = (groppe_framework_active()) ? cs_get_option('theme_gallery_name') : '';
	if ($gallery_cpt === '') $gallery_cp = 'gallery';
  $rules = get_option( 'rewrite_rules' );
  if ( ! ( $rules['('.$gallery_cpt.')/(\d*)$'] ) ) {
		global $wp_rewrite;
		$wp_rewrite->flush_rules();
  }

}
add_action( 'cs_validate_save_after','groppe_custom_project_slug' );

// After Theme Setup
function groppe_custom_flush_rules() {
	// Enter post type function, so rewrite work within this function
	groppe_custom_post_type();
	// Flush it
	flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'groppe_custom_flush_rules');
add_action('init', 'groppe_custom_post_type');

// Avoid project post type as 404 page while it change
function vt_cpt_avoid_error_project() {
	$project_cpt = (groppe_framework_active()) ? cs_get_option('theme_project_name') : '';
	if ($project_cpt === '') $project_cp = 'project';
	$set = get_option('post_type_rules_flased_' . $project_cpt);
	if ($set !== true){
		flush_rewrite_rules(false);
		update_option('post_type_rules_flased_' . $project_cpt,true);
	}
}
add_action('init', 'vt_cpt_avoid_error_project');

// Add Filter by Category in Project Type
add_action('restrict_manage_posts', 'groppe_filter_project_categories');
function groppe_filter_project_categories() {
	global $typenow;
	$post_type = 'project'; // Project post type
	$taxonomy  = 'project_category'; // Project category taxonomy
	if ($typenow == $post_type) {
		$selected      = isset($_GET[$taxonomy]) ? $_GET[$taxonomy] : '';
		$info_taxonomy = get_taxonomy($taxonomy);
		wp_dropdown_categories(array(
			'show_option_all' => sprintf(esc_html__("Show All %s", 'groppe-core'), $info_taxonomy->label),
			'taxonomy'        => $taxonomy,
			'name'            => $taxonomy,
			'orderby'         => 'name',
			'selected'        => $selected,
			'show_count'      => true,
			'hide_empty'      => true,
		));
	};
}

// Project Search => ID to Term
add_filter('parse_query', 'groppe_project_id_term_search');
function groppe_project_id_term_search($query) {
	global $pagenow;
	$post_type = 'project'; // Project post type
	$taxonomy  = 'project_category'; // Project category taxonomy
	$q_vars    = &$query->query_vars;
	if ( $pagenow == 'edit.php' && isset($q_vars['post_type']) && $q_vars['post_type'] == $post_type && isset($q_vars[$taxonomy]) && is_numeric($q_vars[$taxonomy]) && $q_vars[$taxonomy] != 0 ) {
		$term = get_term_by('id', $q_vars[$taxonomy], $taxonomy);
		$q_vars[$taxonomy] = $term->slug;
	}
}

/* ---------------------------------------------------------------------------
 * Custom columns - Project
 * --------------------------------------------------------------------------- */
add_filter("manage_edit-project_columns", "groppe_project_edit_columns");
function groppe_project_edit_columns($columns) {
  $new_columns['cb'] = '<input type="checkbox" />';
  $new_columns['title'] = __('Title', 'groppe-core' );
  $new_columns['thumbnail'] = __('Image', 'groppe-core' );
  $new_columns['project_category'] = __('Categories', 'groppe-core' );
  $new_columns['project_order'] = __('Order', 'groppe-core' );
  $new_columns['date'] = __('Date', 'groppe-core' );

  return $new_columns;
}
add_action('manage_project_posts_custom_column', 'groppe_manage_project_columns', 10, 2);
function groppe_manage_project_columns( $column_name ) {
  global $post;

  switch ($column_name) {

    /* If displaying the 'Image' column. */
    case 'thumbnail':
      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
    break;

    /* If displaying the 'Categories' column. */
    case 'project_category' :

      $terms = get_the_terms( $post->ID, 'project_category' );

      if ( !empty( $terms ) ) {

        $out = array();
        foreach ( $terms as $term ) {
            $out[] = sprintf( '<a href="%s">%s</a>',
            	esc_url( add_query_arg( array( 'post_type' => $post->post_type, 'project_category' => $term->slug ), 'edit.php' ) ),
            	esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'project_category', 'display' ) )
            );
        }
        /* Join the terms, separating them with a comma. */
        echo join( ', ', $out );
      }

      /* If no terms were found, output a default message. */
      else {
        echo '&macr;';
      }

    break;

    case "project_order":
      echo $post->menu_order;
    break;

    /* Just break out of the switch statement for everything else. */
    default :
      break;
    break;

  }
}

/* ---------------------------------------------------------------------------
 * Custom columns - Testimonial
 * --------------------------------------------------------------------------- */
add_filter("manage_edit-testimonial_columns", "groppe_testimonial_edit_columns");
function groppe_testimonial_edit_columns($columns) {
  $new_columns['cb'] = '<input type="checkbox" />';
  $new_columns['title'] = __('Title', 'groppe-core' );
  $new_columns['thumbnail'] = __('Image', 'groppe-core' );
  $new_columns['name'] = __('Client Name', 'groppe-core' );
  $new_columns['date'] = __('Date', 'groppe-core' );

  return $new_columns;
}

add_action('manage_testimonial_posts_custom_column', 'groppe_manage_testimonial_columns', 10, 2);
function groppe_manage_testimonial_columns( $column_name ) {
  global $post;

  switch ($column_name) {

    /* If displaying the 'Image' column. */
    case 'thumbnail':
      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
    break;

    case "name":
    	$testimonial_options = get_post_meta( get_the_ID(), 'testimonial_options', true );
      echo $testimonial_options['testi_name'];
    break;

    /* Just break out of the switch statement for everything else. */
    default :
      break;
    break;

  }
}

/* ---------------------------------------------------------------------------
 * Custom columns - Team
 * --------------------------------------------------------------------------- */
add_filter("manage_edit-team_columns", "groppe_team_edit_columns");
function groppe_team_edit_columns($columns) {
  $new_columns['cb'] = '<input type="checkbox" />';
  $new_columns['title'] = __('Title', 'groppe-core' );
  $new_columns['thumbnail'] = __('Image', 'groppe-core' );
  $new_columns['name'] = __('Job Position', 'groppe-core' );
  $new_columns['date'] = __('Date', 'groppe-core' );

  return $new_columns;
}

add_action('manage_team_posts_custom_column', 'groppe_manage_team_columns', 10, 2);
function groppe_manage_team_columns( $column_name ) {
  global $post;

  switch ($column_name) {

    /* If displaying the 'Image' column. */
    case 'thumbnail':
      echo get_the_post_thumbnail( $post->ID, array( 100, 100) );
    break;

    case "name":
    	$team_options = get_post_meta( get_the_ID(), 'team_options', true );
      echo $team_options['team_job_position'];
    break;

    /* Just break out of the switch statement for everything else. */
    default :
      break;
    break;

  }
}
