<?php
/*
 * All Back-End Helper Functions for Groppe Theme
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com
 */

/* Validate px entered in field */
if( ! function_exists( 'groppe_check_px' ) ) {
  function groppe_check_px( $num ) {
    return ( is_numeric( $num ) ) ? $num . 'px' : $num;
  }
}

/* Escape Strings */
if( ! function_exists( 'groppe_vt_esc_string' ) ) {
  function groppe_vt_esc_string( $num ) {
    return preg_replace('/\D/', '', $num);
  }
}

/* Escape Numbers */
if( ! function_exists( 'groppe_vt_esc_number' ) ) {
  function groppe_vt_esc_number( $num ) {
    return preg_replace('/[^a-zA-Z]/', '', $num);
  }
}

/* Compress CSS */
if ( ! function_exists( 'groppe_compress_css_lines' ) ) {
  function groppe_compress_css_lines( $css ) {
    $css  = preg_replace( '!/\*[^*]*\*+([^/][^*]*\*+)*/!', '', $css );
    $css  = str_replace( ': ', ':', $css );
    $css  = str_replace( array( "\r\n", "\r", "\n", "\t", '  ', '    ', '    ' ), '', $css );
    return $css;
  }
}

/* Inline Style */
global $all_inline_styles;
$all_inline_styles = array();
if( ! function_exists( 'add_inline_style' ) ) {
  function add_inline_style( $style ) {
    global $all_inline_styles;
    array_push( $all_inline_styles, $style );
  }
}

/* Support WordPress uploader to following file extensions */
if( ! function_exists( 'groppe_vt_upload_mimes' ) ) {
  function groppe_vt_upload_mimes( $mimes ) {

    $mimes['ttf']   = 'font/ttf';
    $mimes['eot']   = 'font/eot';
    $mimes['woff']  = 'font/woff';
    $mimes['otf']   = 'font/otf';

    return $mimes;

  }
  add_filter( 'upload_mimes', 'groppe_vt_upload_mimes' );
}

/**
 * TinyMCE Editor
 */

// Enable font size & font family selects in the editor
if ( ! function_exists( 'groppe_tinymce_btns_font' ) ) {
  function groppe_tinymce_btns_font( $buttons ) {
    array_unshift( $buttons, 'fontselect' ); // Add Font Select
    array_unshift( $buttons, 'fontsizeselect' ); // Add Font Size Select
    return $buttons;
  }
  add_filter( 'mce_buttons_2', 'groppe_tinymce_btns_font' );
}

// Customize mce editor font sizes
if ( ! function_exists( 'groppe_tinymce_sizes' ) ) {
  function groppe_tinymce_sizes( $initArray ){
    $initArray['fontsize_formats'] = "9px 10px 12px 13px 14px 16px 18px 21px 24px 28px 32px 36px";
    return $initArray;
  }
  add_filter( 'tiny_mce_before_init', 'groppe_tinymce_sizes' );
}

// Customize mce editor font family
if ( ! function_exists( 'groppe_tinmymce_family' ) ) {
  function groppe_tinmymce_family( $initArray ) {
      $initArray['font_formats'] = 'Amiri=Amiri,serif;Montserrat=Montserrat,sans-serif;Andale Mono=andale mono,times;Arial=arial,helvetica,sans-serif;Arial Black=arial black,avant garde;Book Antiqua=book antiqua,palatino;Comic Sans MS=comic sans ms,sans-serif;Courier New=courier new,courier;Georgia=georgia,palatino;Helvetica=helvetica;Impact=impact,chicago;Symbol=symbol;Tahoma=tahoma,arial,helvetica,sans-serif;Terminal=terminal,monaco;Times New Roman=times new roman,times;Trebuchet MS=trebuchet ms,geneva;Verdana=verdana,geneva;Webdings=webdings;Wingdings=wingdings,zapf dingbats';
            return $initArray;
  }
  add_filter( 'tiny_mce_before_init', 'groppe_tinmymce_family' );
}

/* HEX to RGB */
if( ! function_exists( 'groppe_vt_hex2rgb' ) ) {
  function groppe_vt_hex2rgb( $hexcolor, $opacity = 1 ) {

    if( preg_match( '/^#[a-fA-F0-9]{6}|#[a-fA-F0-9]{3}$/i', $hexcolor ) ) {

      $hex    = str_replace( '#', '', $hexcolor );

      if( strlen( $hex ) == 3 ) {
        $r    = hexdec( substr( $hex, 0, 1 ) . substr( $hex, 0, 1 ) );
        $g    = hexdec( substr( $hex, 1, 1 ) . substr( $hex, 1, 1 ) );
        $b    = hexdec( substr( $hex, 2, 1 ) . substr( $hex, 2, 1 ) );
      } else {
        $r    = hexdec( substr( $hex, 0, 2 ) );
        $g    = hexdec( substr( $hex, 2, 2 ) );
        $b    = hexdec( substr( $hex, 4, 2 ) );
      }

      return ( isset( $opacity ) && $opacity != 1 ) ? 'rgba('. $r .', '. $g .', '. $b .', '. $opacity .')' : ' ' . $hexcolor;

    } else {

      return $hexcolor;

    }

  }
}

/* Yoast Plugin Metabox Low */
if( ! function_exists( 'groppe_vt_yoast_metabox' ) ) {
  function groppe_vt_yoast_metabox() {
    return 'low';
  }
  add_filter( 'wpseo_metabox_prio', 'groppe_vt_yoast_metabox' );
}

if( ! function_exists( 'is_post_type' ) ) {
  function is_post_type($type){
    global $wp_query;
    if($type == get_post_type($wp_query->post->ID)) return true;
    return false;
  }
}

/**
 * If WooCommerce Plugin Activated
 */
if ( ! function_exists( 'is_woocommerce_activated' ) ) {
  function is_woocommerce_activated() {
    if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
  }
}

/**
 * If is WooCommerce Shop
 */
if ( ! function_exists( 'is_woocommerce_shop' ) ) {
  function is_woocommerce_shop() {
    if ( is_woocommerce_activated() && is_shop() ) { return true; } else { return false; }
  }
}

/**
 * If Tribe Event Plugin Activated
 */
if ( ! function_exists( 'is_tribe_activated' ) ) {
  function is_tribe_activated() {
    if( function_exists( 'tribe_is_event' ) ) { return true; } else { return false; }
  }
}

/**
 * If is Single Tribe Event
 */
if ( ! function_exists( 'tribee_is_event()' ) ) {
  function tribee_is_event() {
    if ( is_tribe_activated() && tribe_is_event() && is_single() ) { return true; } else { return false; }
  }
}

/**
 * If is WPML is active
 */
if ( ! function_exists( 'is_wpml_activated' ) ) {
  function is_wpml_activated() {
    if ( class_exists( 'SitePress' ) ) { return true; } else { return false; }
  }
}

/**
 * Remove Rev Slider Metabox
 */
if ( is_admin() ) {

  if( ! function_exists( 'groppe_remove_rev_slider_meta_boxes' ) ) {
    function groppe_remove_rev_slider_meta_boxes() {
      remove_meta_box( 'mymetabox_revslider_0', 'page', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'post', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'team', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'testimonial', 'normal' );
      remove_meta_box( 'mymetabox_revslider_0', 'project', 'normal' );
    }
    add_action( 'do_meta_boxes', 'groppe_remove_rev_slider_meta_boxes' );
  }

}

// Adding share option in single event
if ( ! function_exists( 'groppe_event_share' ) ) {
  function groppe_event_share() {
    $groppe_single_share_option = cs_get_option('event_share_option');
    if($groppe_single_share_option) {
      if ( function_exists( 'groppe_wp_share_option' ) ) {
        echo groppe_wp_share_option();
      }
    }
  }
  add_action('tribe_events_single_event_after_the_meta','groppe_event_share');
}

// Adding register form button in single event
if ( ! function_exists( 'groppe_event_register_button' ) ) {
  function groppe_event_register_button() {
    $event_popup_options = get_post_meta( get_the_ID(), '_event_popup_form_metabox', true );
    if ($event_popup_options) {
      $buy_ticket_button_link= $event_popup_options['buy_btn_link'];
      if ($event_popup_options['popup_btn']) {
      $event_contact_btn = $event_popup_options['popup_btn'];
      $event_popup_form_id = $event_popup_options['form_id'];
      $event_contact_btn_type = $event_popup_options['contact_btn_type'];
      $event_contact_btn_link = $event_popup_options['contact_btn_link'] ? $event_popup_options['contact_btn_link'] : cs_get_option('contact_btn_link');
      } else {
        $event_contact_btn = cs_get_option('popup_btn');
        $event_popup_form_id = cs_get_option('form_id');
        $event_contact_btn_type = cs_get_option('contact_btn_type');
        $event_contact_btn_link = cs_get_option('contact_btn_link');
      }
    } else {
      $event_contact_btn = cs_get_option('popup_btn');
      $event_popup_form_id = cs_get_option('form_id');
      $event_contact_btn_type = cs_get_option('contact_btn_type');
      $event_contact_btn_link = cs_get_option('contact_btn_link');
      $buy_ticket_button_link= '';
    }
    if ($event_contact_btn) { ?>
      <div class="text-right  grop-evensigl_rebtn_warp">
        <?php if ($event_contact_btn_type === 'popup') { ?>
        <a class="grop-btn grop-btn_overly grop-evensiglre_btn" href="#<?php echo esc_attr($event_popup_form_id); ?>"  data-toggle="modal" data-target="#<?php echo esc_attr($event_popup_form_id); ?>">
            <span><?php echo esc_html__( 'Register Now', 'groppe' ); ?></span>
          </a>
        <?php } else { ?>
          <a class="grop-btn grop-btn_overly grop-evensiglre_btn" href="<?php echo esc_url($event_contact_btn_link); ?>">
            <span><?php echo esc_html__( 'Register Now', 'groppe' ); ?></span>
          </a>
        <?php } ?>
      </div>
      <?php if ( function_exists( 'groppe_event_popup_form' ) ) {
        groppe_event_popup_form();
      }
   }
  }
  add_action('tribe_events_single_event_after_the_content','groppe_event_register_button');
}

// Adding extra feature image for aligning content in one div in day view
if ( ! function_exists( 'groppe_add_featured_image' ) ) {
  function groppe_add_featured_image() {
    echo '<div class="list-featured-image">';
    echo tribe_event_featured_image( null, 'medium' );
    echo '</div>';
  }
  add_action('tribe_events_before_the_event_title','groppe_add_featured_image');
}

// Adding mail icon and share option in event list view
if ( ! function_exists( 'groppe_list_view_share' ) ) {
  function groppe_list_view_share() {
    $event_style = cs_get_option('event_styles');
     $event_popup_options = get_post_meta( get_the_ID(), '_event_popup_form_metabox', true );
    if ($event_popup_options) {
      if ($event_popup_options['popup_btn']){
        $event_contact_btn = $event_popup_options['popup_btn'];
        $event_popup_form_id = $event_popup_options['form_id'];
        $event_contact_btn_type = $event_popup_options['contact_btn_type'];
        $event_contact_btn_link = $event_popup_options['contact_btn_link'] ? $event_popup_options['contact_btn_link'] : cs_get_option('contact_btn_link');
      } else {
        $event_contact_btn = cs_get_option('popup_btn');
        $event_popup_form_id = cs_get_option('form_id');
        $event_contact_btn_type = cs_get_option('contact_btn_type');
        $event_contact_btn_link = cs_get_option('contact_btn_link');
      }
    } else {
      $event_contact_btn = cs_get_option('popup_btn');
      $event_popup_form_id = cs_get_option('form_id');
      $event_contact_btn_type = cs_get_option('contact_btn_type');
      $event_contact_btn_link = cs_get_option('contact_btn_link');
    }
    ?>
    <div class="grop-fix  grop-ucoming_evnt_footr">
      <div class="grop-fix  grop-float_left  grop-ucoming_evnt_social">
        <div class="grop-ucoevnt_socil">
          <?php if ($event_contact_btn) {
            if ($event_contact_btn_type === 'popup') { ?>
              <a class="grop-evs_evpop" href="mailto:?subject=<?php print(urlencode( get_the_title() )); ?>&amp;body=<?php print(urlencode( get_permalink( get_the_ID() ) )); ?>" data-toggle="modal" data-target="#<?php echo esc_attr($event_popup_form_id); ?>"><i class="fa fa-envelope-o"></i></a>
            <?php } else { ?>
              <a href="<?php echo esc_url($event_contact_btn_link); ?>" target="_blank" class="grop-evs_evpop"><i class="fa fa-envelope-o"></i></a>
            <?php }
          }
          if ( function_exists( 'groppe_event_share_option' ) ) {
            echo groppe_event_share_option();
          }
          ?>
        </div>
      </div>
    </div> <?php
  }
  add_action('tribe_events_after_the_content','groppe_list_view_share');
}

// Adding countown in single event
if ( ! function_exists( 'groppe_event_countown' ) ) {
  function groppe_event_countown() {
    $event_popup_options = get_post_meta( get_the_ID(), '_event_popup_form_metabox', true );
    if ($event_popup_options) {
      $buy_ticket_button_link= $event_popup_options['buy_btn_link'];
      if ($event_popup_options['popup_btn']) {
      $event_contact_btn = $event_popup_options['popup_btn'];
      $event_popup_form_id = $event_popup_options['form_id'];
      $event_contact_btn_type = $event_popup_options['contact_btn_type'];
      $event_contact_btn_link = $event_popup_options['contact_btn_link'] ? $event_popup_options['contact_btn_link'] : cs_get_option('contact_btn_link');

      } else {
        $event_contact_btn = cs_get_option('popup_btn');
        $event_popup_form_id = cs_get_option('form_id');
        $event_contact_btn_type = cs_get_option('contact_btn_type');
        $event_contact_btn_link = cs_get_option('contact_btn_link');
      }
    } else {
      $event_contact_btn = cs_get_option('popup_btn');
      $event_popup_form_id = cs_get_option('form_id');
      $event_contact_btn_type = cs_get_option('contact_btn_type');
      $event_contact_btn_link = cs_get_option('contact_btn_link');
      $buy_ticket_button_link= '';
    }

    $post_meta = get_post_meta( get_the_ID() );
    $event_countdown_option = cs_get_option('event_countdown_option');
    $s_date = $post_meta['_EventStartDate'];
    $diff = strtotime($s_date[0])-time();
    if($diff > 0) {
    if($event_countdown_option) {} else { ?>

      <div class="grop-flax_vr-middle grop-fix grop-evensiglcnd_warp">
        <!--countdown  clock counter start  \-->
        <div class="grop-countdown">
          <div class="grop-flipclock"
            data-clockface="DailyCounter"
            data-diff="<?php echo esc_attr( $diff ); ?>"
            data-autoplay="true"
            data-autostart="false"
            data-countdown="true"
            data-defaultlanguage="<?php echo get_locale(); ?>"
            data-minimumdigits="0">
          </div>
        </div><!--/countdown clock counter end-->

        <!--Events Details btn start  \-->
        <div class="text-right grop-cntdwn_evt_btn_wrp">
          <a class="grop-btn grop-btn_overly grop-cntdwn_evt_btn" target="_blank" href="<?php echo $buy_ticket_button_link ?>">
            <span><?php echo esc_html__( 'Buy Ticket Online', 'groppe' ); ?></span>
          </a>
        </div><!--/ end-->
      </div>
    <?php } }
  }
  add_action('tribe_events_single_event_after_the_content','groppe_event_countown');
}
